idwt

Function idwt 

pub fn idwt<T: SignalType>(
    approximation: &Signal<T>,
    detail: &Signal<T>,
    wavelet: &dyn Wavelet,
    boundary: BoundaryMode,
    original_length: usize,
) -> Result<Signal<T>>
Perform Inverse Discrete Wavelet Transform.

original_length is the length of the signal that produced approximation/detail. It is required because the truncation rule is mode-dependent (Periodic truncates a 2·M reconstruction; non- Periodic extracts the central N samples from a 2·M + L − 2 reconstruction) and M + filter length alone cannot recover N (parity ambiguity). For a DWTResult use result.original_length.